local PetBattle = select(2, ...)
local L, MAX_PETS, MAX_ABILITIES = PetBattle.L, PetBattle.MAX_PETS, PetBattle.MAX_ABILITIES

local Vs = PetBattle:RegisterModule("Vs")

function Vs:Update(battlePets)
	if( not PetBattle.db.showVs ) then return end

end

function Vs:SetStatus()
	if( PetBattle.db.showAbilities ) then
		self:Create()
	else
		self:Reset()
	end
end

function Vs:Reset()
	if( not self.frame ) then return end

	self.frame:Hide()
end


function Vs:CreateUI()
	if( self.frame ) then return end
	if( not PetBattle.db.showVs ) then return end
--[[
	-- Container frame
	self.frame = CreateFrame("Frame", nil, UIParent)
	self.frame:SetWidth(365)
	self.frame:SetMovable(true)
	self.frame:EnableMouse(true)
	self.frame:SetClampedToScreen(true)
	
	self.frame:SetBackdrop({
		bgFile = "Interface\\CharacterFrame\\UI-Party-Background",
		edgeFile = "Interface\\DialogFrame\\UI-DialogBox-Border",
		tile = true,
		tileSize = 32,
		edgeSize = 32,
		insets = {left = 10, right = 10, top = 10, bottom = 10},
	})
	
	self.frame:SetBackdropColor(0, 0, 0, 0.90)

	-- Create the title/movy thing
	local texture = self.frame:CreateTexture(nil, "ARTWORK")
	texture:SetTexture("Interface\\DialogFrame\\UI-DialogBox-Header")
	texture:SetPoint("TOP", 0, 13)
	texture:SetWidth(240)
	texture:SetHeight(60)
	
	local title = CreateFrame("Button", nil, self.frame)
	title:SetPoint("TOP", 0, 4)
	title:SetText(L["Pets Vs"])
	title:SetPushedTextOffset(0, 0)
	title:SetNormalFontObject(GameFontNormal)
	title:SetHeight(20)
	title:SetWidth(200)

	title:SetScript("OnEnter", function(self)
		GameTooltip:SetOwner(self, "ANCHOR_TOPLEFT")
		GameTooltip:SetText(L["Alt + Left Click to drag"])
	end)
	title:SetScript("OnLeave", PetBattle.HideTooltip)

	title:RegisterForDrag("LeftButton")
	title:SetScript("OnDragStart", function(self)
		if( IsAltKeyDown() ) then
			self.isMoving = true
			self:GetParent():StartMoving()
		end
	end)
	
	title:SetScript("OnDragStop", function(self)
		if( not self.isMoving ) then return end

		self.isMoving = nil

		local parent = self:GetParent()
		parent:StopMovingOrSizing()

		--local scale = parent:GetEffectiveScale()
		local scale = 1
		PetBattle.db.vsPosition = {x = parent:GetLeft() * scale, y = parent:GetTop() * scale}
	end)
	
	if( PetBattle.db.vsPosition ) then
		--local scale = self.frame:GetEffectiveScale()
		local scale = 1
		self.frame:ClearAllPoints()
		self.frame:SetPoint("TOPLEFT", UIParent, "BOTTOMLEFT", PetBattle.db.vsPosition.x / scale, PetBattle.db.vsPosition.y / scale)
	else
		self.frame:SetPoint("CENTER")
	end

	self.frame.rows = {}

	for petSlot=1, MAX_PETS do
		local row = CreateFrame("Frame", nil, self.frame)
		row:SetHeight(80)
		row:Hide()

		row.icon = row:CreateTexture(nil, "ARTWORK")
		row.icon:SetPoint("TOPLEFT", row, "TOPLEFT")
		row.icon:SetSize(28, 28)

		row.name = CreateFrame("Button", nil, row)
		row.name:SetNormalFontObject(GameFontNormal)
		row.name:SetHighlightFontObject(GameFontHighlight)
		row.name:SetWidth(245)
		row.name:SetHeight(20)
		row.name:SetScript("OnEnter", function(self) PetBattle.ShowPetTooltip(self:GetParent(), self) end)
		row.name:SetScript("OnLeave", function(self) PetBattle.HidePetTooltip(self:GetParent(), self) end)
		row.name:SetPushedTextOffset(0, 0)
		row.name:SetPoint("TOPLEFT", row.icon, "TOPRIGHT", 14, -2)

		row.name:SetText("*")
		row.name.fs = row.name:GetFontString()
		row.name.fs:SetWordWrap(false)
		row.name.fs:SetWidth(row.name:GetWidth())
		row.name.fs:SetJustifyH("LEFT")

		row.abilities = {}

		for abilitySlot=1, MAX_ABILITIES do
			local ability = CreateFrame("Frame", nil, row)
			ability:SetScript("OnEnter", PetBattle.ShowAbilityTooltip)
			ability:SetScript("OnLeave", PetBattle.HideAbilityTooltip)
			ability:SetWidth(100)
			ability:SetHeight(50)
			ability:Hide()

			ability.icon = ability:CreateTexture(nil, "ARTWORK")
			ability.icon:SetPoint("TOPLEFT", ability, "TOPLEFT")
			ability.icon:SetSize(22, 22)

			ability.cooldown = ability:CreateFontString(nil, "OVERLAY", "GameFontNormalLarge")
			ability.cooldown:SetPoint("CENTER", ability.icon)

 			ability.shadow = ability:CreateTexture(nil, "OVERLAY", "BattleBar-Countdown-Shadow")
			ability.shadow:ClearAllPoints()
			ability.shadow:SetSize(26, 26)
			ability.shadow:SetPoint("CENTER", ability.icon)

			ability.petType = ability:CreateTexture(nil, "ARTWORK")
			ability.petType:SetPoint("TOPLEFT", ability.icon, "TOPRIGHT", 8, 0)
			ability.petType:SetTexCoord(0.79687500, 0.49218750, 0.50390625, 0.65625000)
			ability.petType:SetSize(22, 22)

			ability.modifierIcon = ability:CreateTexture(nil, "ARTWORK")
			ability.modifierIcon:SetPoint("TOPLEFT", ability.petType, "TOPRIGHT", 0, 6)
			ability.modifierIcon:SetSize(34, 34)

			ability.name = ability:CreateFontString(nil, "OVERLAY", "GameFontNormal")
			ability.name:SetPoint("TOPLEFT", ability.icon, "BOTTOMLEFT", 0, -6)

			ability.tag = ability:CreateFontString(nil, "OVERLAY", "GameFontHighlight")
			ability.tag:SetPoint("TOPLEFT", ability.name, "BOTTOMLEFT", 0, -2)

			if( abilitySlot > 1 ) then
				ability:SetPoint("TOPLEFT", row.abilities[abilitySlot - 1], "TOPRIGHT", 14, 0)
			else
				ability:SetPoint("TOPLEFT", row, "TOPLEFT", 2, -36) 
			end

			row.abilities[abilitySlot] = ability
		end

		if( petSlot > 1 ) then
			row:SetPoint("TOPLEFT", self.frame.rows[petSlot - 1], "BOTTOMLEFT", 0, -20)
			row:SetPoint("TOPRIGHT", self.frame.rows[petSlot - 1], "BOTTOMRIGHT", 0, 0)
		else
			row:SetPoint("TOPLEFT", self.frame, "TOPLEFT", 16, -32)
			row:SetPoint("TOPRIGHT", self.frame, "TOPRIGHT")
		end

		self.frame.rows[petSlot] = row
	end
]]
end